@@ -77,7 +77,6 @@ public:
         mProductId = other.mProductId;
         mRevision = other.mRevision;
         mSortString = other.mSortString;
-        mUrl = other.mUrl;
         mSecrecy = other.mSecrecy;
         mLogo = other.mLogo;
         mPhoto = other.mPhoto;
@@ -129,7 +128,6 @@ public:
     QString mProductId;
     QDateTime mRevision;
     QString mSortString;
-    ResourceLocatorUrl mUrl;
     Secrecy mSecrecy;
     Picture mLogo;
     Picture mPhoto;
@@ -322,12 +320,6 @@ bool Addressee::operator==(const Addressee &addressee) const
         return false;
     }
 
-    if ((d->mUrl.isValid() || addressee.d->mUrl.isValid()) &&
-            (d->mUrl != addressee.d->mUrl)) {
-        qCDebug(KCONTACTS_LOG) << "url differs";
-        return false;
-    }
-
     if (!listEquals(d->mPhoneNumbers, addressee.d->mPhoneNumbers)) {
         qCDebug(KCONTACTS_LOG) << "phoneNumbers differs";
         return false;
@@ -475,6 +467,7 @@ QString Addressee::kind() const
 
 void Addressee::insertExtraSound(const Sound &sound)
 {
+    d->mEmpty = false;
     d->mSoundListExtra.append(sound);
 }
 
@@ -485,6 +478,7 @@ Sound::List Addressee::extraSoundList() const
 
 void Addressee::insertExtraPhoto(const Picture &picture)
 {
+    d->mEmpty = false;
     d->mPhotoExtraList.append(picture);
 }
 
@@ -495,6 +489,7 @@ Picture::List Addressee::extraPhotoList() const
 
 void Addressee::insertExtraLogo(const Picture &logo)
 {
+    d->mEmpty = false;
     d->mLogoExtraList.append(logo);
 }
 
@@ -505,26 +500,31 @@ Picture::List Addressee::extraLogoList() const
 
 void Addressee::setExtraSoundList(const Sound::List &soundList)
 {
+    d->mEmpty = false;
     d->mSoundListExtra = soundList;
 }
 
 void Addressee::setExtraPhotoList(const Picture::List &pictureList)
 {
+    d->mEmpty = false;
     d->mPhotoExtraList = pictureList;
 }
 
 void Addressee::setExtraLogoList(const Picture::List &logoList)
 {
+    d->mEmpty = false;
     d->mLogoExtraList = logoList;
 }
 
 void Addressee::insertExtraUrl(const ResourceLocatorUrl &url)
 {
+    d->mEmpty = false;
     d->mUrlExtraList.append(url);
 }
 
 void Addressee::setExtraUrlList(const ResourceLocatorUrl::List &urlList)
 {
+    d->mEmpty = false;
     d->mUrlExtraList = urlList;
 }
 
@@ -535,11 +535,13 @@ ResourceLocatorUrl::List Addressee::extraUrlList() const
 
 void Addressee::insertSourceUrl(const QUrl &url)
 {
+    d->mEmpty = false;
     d->mSources.append(url);
 }
 
 void Addressee::setSourcesUrlList(const QVector<QUrl> &urlList)
 {
+    d->mEmpty = false;
     d->mSources = urlList;
 }
 
@@ -1081,27 +1083,21 @@ void Addressee::setUrl(const QUrl &url)
 {
     KContacts::ResourceLocatorUrl resourceLocator;
     resourceLocator.setUrl(url);
-    if (resourceLocator == d->mUrl) {
-        return;
-    }
-
-    d->mEmpty = false;
-    d->mUrl = resourceLocator;
+    insertExtraUrl(resourceLocator);
 }
 
 void Addressee::setUrl(const ResourceLocatorUrl &url)
 {
-    if (url == d->mUrl) {
-        return;
-    }
-
-    d->mEmpty = false;
-    d->mUrl = url;
+    insertExtraUrl(url);
 }
 
 ResourceLocatorUrl Addressee::url() const
 {
-    return d->mUrl;
+    if (d->mUrlExtraList.isEmpty()) {
+        return ResourceLocatorUrl();
+    } else {
+        return d->mUrlExtraList.at(0);
+    }
 }
 
 QString Addressee::urlLabel()
@@ -1591,6 +1587,13 @@ PhoneNumber::List Addressee::phoneNumbers() const
     return d->mPhoneNumbers;
 }
 
+void Addressee::setPhoneNumbers(const PhoneNumber::List &phoneNumbers)
+{
+    d->mEmpty = false;
+    d->mPhoneNumbers.clear();
+    d->mPhoneNumbers = phoneNumbers;
+}
+
 PhoneNumber::List Addressee::phoneNumbers(PhoneNumber::Type type) const
 {
     PhoneNumber::List list;
@@ -1631,23 +1634,10 @@ void Addressee::insertKey(const Key &key)
     d->mKeys.append(key);
 }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
 void vectorRemoveAll(Key::List &t, const Key &key)
 {
     t.removeAll(key);
 }
-#else
-void vectorRemoveAll(Key::List &vector, const Key &t)
-{
-    for (Key::List::iterator it = vector.begin(), itEnd = vector.end(); it != itEnd;) {
-        if (*it == t) {
-            it = vector.erase(it);
-        } else {
-            ++it;
-        }
-    }
-}
-#endif
 
 void Addressee::removeKey(const Key &key)
 {
@@ -2262,7 +2252,6 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mProductId;
     s << a.d->mRevision;
     s << a.d->mSortString;
-    s << a.d->mUrl;
     s << a.d->mSecrecy;
     s << a.d->mLogo;
     s << a.d->mPhoto;
@@ -2313,7 +2302,6 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mProductId;
     s >> a.d->mRevision;
     s >> a.d->mSortString;
-    s >> a.d->mUrl;
     s >> a.d->mSecrecy;
     s >> a.d->mLogo;
     s >> a.d->mPhoto;
